==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { typeCast, runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var LineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LineSeries, _super);
    function LineSeries() {
        var _this = _super.call(this) || this;
        _this.uo = null;
        _this.uo = new CategoryLineRasterizer();
        _this.ab = LineSeries.$;
        _this.t8 = 0;
        return _this;
    }
    LineSeries.prototype.get_dx = function () {
        return true;
    };
    LineSeries.prototype.bv = function () {
        return new LineSeriesView(this);
    };
    LineSeries.prototype.lo = function (a) {
        _super.prototype.lo.call(this, a);
        this.up = a;
    };
    LineSeries.prototype.get_da = function () {
        return true;
    };
    LineSeries.prototype.preferredCategoryMode = function (a) {
        return this.t8;
    };
    LineSeries.prototype.ko = function (a, b) {
        _super.prototype.ko.call(this, a, b);
        var c = b;
        c.db();
    };
    LineSeries.prototype.su = function (a, b) {
        _super.prototype.su.call(this, a, b);
        var c = b.cr.d;
        var d = typeCast(LineSeriesView.$, b);
        var e = a.f;
        var f = this.getEffectiveViewport1(b);
        this.rk.a0(this, this.r4(), runOn(this, this.q5), this.sc(b), this.sd(b));
        var g = false;
        var h = this.rk.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            var i = new ScalerParams(0, b.bv, b.bu, this.t5.cf, f);
            this.sq(e, -1, this.valueColumn.count, this.t5, i, b.q);
        }
        var j = d.dh;
        var k = d.di;
        var l = d.dg;
        this.rk.ad(j, true, false, true, false);
        this.rk.ad(k, true, false, true, false);
        this.rk.ad(l, false, true, false, false);
        l._opacity = 0.75 * this.rk.j;
        if (b.cv(a)) {
            d.dc(e.count, e, true, this.unknownValuePlotting, this.s2(e, e.count - 1, b.bu, b.bv), c, this.gk);
            b.cy(a);
        }
    };
    LineSeries.prototype.lt = function (a, b, c, d) {
        _super.prototype.lt.call(this, a, b, c, d);
        switch (b) {
            case LineSeries.$$p[0]:
                this.rh.m = this.unknownValuePlotting == 0;
                this.l7(false);
                this.le();
                break;
        }
    };
    Object.defineProperty(LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.r7;
        },
        enumerable: false,
        configurable: true
    });
    LineSeries.$t = markType(LineSeries, 'LineSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    LineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, LineSeries, 'raisePropertyChanged', ['UnknownValuePlotting::ur', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return LineSeries;
}(HorizontalAnchoredCategorySeries));
export { LineSeries };
/**
 * @hidden
 */
var LineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LineSeriesView, _super);
    function LineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.dk = new Path();
        _this.dj = new Path();
        _this.dl = new Path();
        _this.df = new Path();
        _this.de = new Path();
        _this.dd = new Path();
        _this.da = a;
        return _this;
    }
    LineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.da.p0 = Defaults.e;
        }
    };
    Object.defineProperty(LineSeriesView.prototype, "dh", {
        get: function () {
            return this.dk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "di", {
        get: function () {
            return this.dl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "dg", {
        get: function () {
            return this.dj;
        },
        enumerable: false,
        configurable: true
    });
    LineSeriesView.prototype.db = function () {
        this.dj.ak = null;
        this.dk.ak = null;
        this.dl.ak = null;
        this.aq();
    };
    LineSeriesView.prototype.dc = function (a, b, c, d, e, f, g) {
        this.da.uo.a = typeCast(ISortingAxis_$type, this.ct.fetchXAxis()) !== null ? true : false;
        this.da.uo.m(this.dk, this.dj, this.dl, a, b, c, d, e, f, g);
        this.aq();
    };
    LineSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    LineSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        this.de.ak = this.dk.ak;
        this.df.ak = this.dl.ak;
        this.dd.ak = this.dj.ak;
        var a = this.bo();
        this.de._stroke = a;
        this.de.ac = this.e.fn + 3;
        this.df._stroke = a;
        this.df.ac = this.e.fn + 3;
        this.dd._fill = a;
        this.dd._opacity = 1;
    };
    LineSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.dd);
                a.s(this.de);
                a.s(this.df);
            }
            else {
                a.s(this.dj);
                a.s(this.dk);
                a.s(this.dl);
            }
        }
    };
    LineSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a7.exportPathData(a, this.dk, "lowerShape", ["Lower", "Main"]);
        this.e.a7.exportPathData(a, this.dl, "upperShape", ["Upper"]);
        this.e.a7.exportPathData(a, this.dj, "translucentShape", ["Translucent"]);
    };
    LineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.o0 = a;
        this.e.gm = 3;
        this.e.gn = 1;
        this.e.go = 4;
        this.e.e3 = false;
    };
    LineSeriesView.$t = markType(LineSeriesView, 'LineSeriesView', AnchoredCategorySeriesView.$);
    return LineSeriesView;
}(AnchoredCategorySeriesView));
export { LineSeriesView };

==> igniteui-react-charts-16.16.3.tgz: package/esm5/lib/LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { typeCast, runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var LineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LineSeries, _super);
    function LineSeries() {
        var _this = _super.call(this) || this;
        _this.u7 = null;
        _this.u7 = new CategoryLineRasterizer();
        _this.ab = LineSeries.$;
        _this.ur = 0;
        return _this;
    }
    LineSeries.prototype.get_d1 = function () {
        return true;
    };
    LineSeries.prototype.bx = function () {
        return new LineSeriesView(this);
    };
    LineSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.u8 = a;
    };
    LineSeries.prototype.get_de = function () {
        return true;
    };
    LineSeries.prototype.preferredCategoryMode = function (a) {
        return this.ur;
    };
    LineSeries.prototype.kx = function (a, b) {
        _super.prototype.kx.call(this, a, b);
        var c = b;
        c.db();
    };
    LineSeries.prototype.s7 = function (a, b) {
        _super.prototype.s7.call(this, a, b);
        var c = b.cr.d;
        var d = typeCast(LineSeriesView.$, b);
        var e = a.f;
        var f = this.getEffectiveViewport1(b);
        this.rx.a0(this, this.sh(), runOn(this, this.ri), this.sp(b), this.sq(b));
        var g = false;
        var h = this.rx.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            var i = new ScalerParams(0, b.bv, b.bu, this.uo.cg, f);
            this.s3(e, -1, this.valueColumn.count, this.uo, i, b.q);
        }
        var j = d.dh;
        var k = d.di;
        var l = d.dg;
        this.rx.ad(j, true, false, true, false);
        this.rx.ad(k, true, false, true, false);
        this.rx.ad(l, false, true, false, false);
        l._opacity = 0.75 * this.rx.j;
        if (b.cv(a)) {
            d.dc(e.count, e, true, this.unknownValuePlotting, this.tf(e, e.count - 1, b.bu, b.bv), c, this.ft);
            b.cy(a);
        }
    };
    LineSeries.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
        switch (b) {
            case LineSeries.$$p[0]:
                this.ru.m = this.unknownValuePlotting == 0;
                this.mi(false);
                this.lp();
                break;
        }
    };
    Object.defineProperty(LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.sk;
        },
        enumerable: false,
        configurable: true
    });
    LineSeries.$t = markType(LineSeries, 'LineSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    LineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, LineSeries, 'raisePropertyChanged', ['UnknownValuePlotting::va', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return LineSeries;
}(HorizontalAnchoredCategorySeries));
export { LineSeries };
/**
 * @hidden
 */
var LineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LineSeriesView, _super);
    function LineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.dk = new Path();
        _this.dj = new Path();
        _this.dl = new Path();
        _this.df = new Path();
        _this.de = new Path();
        _this.dd = new Path();
        _this.da = a;
        return _this;
    }
    LineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.da.qd = Defaults.e;
        }
    };
    Object.defineProperty(LineSeriesView.prototype, "dh", {
        get: function () {
            return this.dk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "di", {
        get: function () {
            return this.dl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "dg", {
        get: function () {
            return this.dj;
        },
        enumerable: false,
        configurable: true
    });
    LineSeriesView.prototype.db = function () {
        this.dj.ak = null;
        this.dk.ak = null;
        this.dl.ak = null;
        this.aq();
    };
    LineSeriesView.prototype.dc = function (a, b, c, d, e, f, g) {
        this.da.u7.a = typeCast(ISortingAxis_$type, this.ct.fetchXAxis()) !== null ? true : false;
        this.da.u7.m(this.dk, this.dj, this.dl, a, b, c, d, e, f, g);
        this.aq();
    };
    LineSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    LineSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        this.de.ak = this.dk.ak;
        this.df.ak = this.dl.ak;
        this.dd.ak = this.dj.ak;
        var a = this.bo();
        this.de._stroke = a;
        this.de.ac = this.e.fu + 3;
        this.df._stroke = a;
        this.df.ac = this.e.fu + 3;
        this.dd._fill = a;
        this.dd._opacity = 1;
    };
    LineSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.dd);
                a.s(this.de);
                a.s(this.df);
            }
            else {
                a.s(this.dj);
                a.s(this.dk);
                a.s(this.dl);
            }
        }
    };
    LineSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.dk, "lowerShape", ["Lower", "Main"]);
        this.e.a8.exportPathData(a, this.dl, "upperShape", ["Upper"]);
        this.e.a8.exportPathData(a, this.dj, "translucentShape", ["Translucent"]);
    };
    LineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pb = a;
        this.e.gw = 3;
        this.e.gx = 1;
        this.e.gy = 4;
        this.e.e7 = false;
    };
    LineSeriesView.$t = markType(LineSeriesView, 'LineSeriesView', AnchoredCategorySeriesView.$);
    return LineSeriesView;
}(AnchoredCategorySeriesView));
export { LineSeriesView };
